Exception: Middlegem::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/middlegem.rb

Overview

Error is a subclass of StandardError from which all custom errors in middlegem are derived. One potential use for this class is to rescue all custom errors produced by middlegem. For example:

begin
# Do something risky with middlegem here...
rescue Middlegem::Error
# Catch any middlegem-specific error here...
end